import terrascript.core as core


@core.resource(type="aws_qldb_ledger", namespace="qldb")
class Ledger(core.Resource):
    """
    The ARN of the QLDB Ledger
    """

    arn: str | core.StringOut = core.attr(str, computed=True)

    """
    (Optional) The deletion protection for the QLDB Ledger instance. By default it is `true`. To delete
    this resource via Terraform, this value must be configured to `false` and applied first before attem
    pting deletion.
    """
    deletion_protection: bool | core.BoolOut | None = core.attr(bool, default=None)

    """
    The Name of the QLDB Ledger
    """
    id: str | core.StringOut = core.attr(str, computed=True)

    """
    (Optional) The key in AWS Key Management Service (AWS KMS) to use for encryption of data at rest in
    the ledger. For more information, see the [AWS documentation](https://docs.aws.amazon.com/qldb/lates
    t/developerguide/encryption-at-rest.html). Valid values are `"AWS_OWNED_KMS_KEY"` to use an AWS KMS
    key that is owned and managed by AWS on your behalf, or the ARN of a valid symmetric customer manage
    d KMS key.
    """
    kms_key: str | core.StringOut | None = core.attr(str, default=None, computed=True)

    """
    (Optional) The friendly name for the QLDB Ledger instance. By default generated by Terraform.
    """
    name: str | core.StringOut | None = core.attr(str, default=None, computed=True)

    """
    (Required) The permissions mode for the QLDB ledger instance. Specify either `ALLOW_ALL` or `STANDAR
    D`.
    """
    permissions_mode: str | core.StringOut = core.attr(str)

    """
    (Optional) Key-value map of resource tags. If configured with a provider [`default_tags` configurati
    on block](https://registry.terraform.io/providers/hashicorp/aws/latest/docs#default_tags-configurati
    on-block) present, tags with matching keys will overwrite those defined at the provider-level.
    """
    tags: dict[str, str] | core.MapOut[core.StringOut] | None = core.attr(
        str, default=None, kind=core.Kind.map
    )

    """
    A map of tags assigned to the resource, including those inherited from the provider [`default_tags`
    configuration block](https://registry.terraform.io/providers/hashicorp/aws/latest/docs#default_tags-
    configuration-block).
    """
    tags_all: dict[str, str] | core.MapOut[core.StringOut] | None = core.attr(
        str, default=None, computed=True, kind=core.Kind.map
    )

    def __init__(
        self,
        resource_name: str,
        *,
        permissions_mode: str | core.StringOut,
        deletion_protection: bool | core.BoolOut | None = None,
        kms_key: str | core.StringOut | None = None,
        name: str | core.StringOut | None = None,
        tags: dict[str, str] | core.MapOut[core.StringOut] | None = None,
        tags_all: dict[str, str] | core.MapOut[core.StringOut] | None = None,
        depends_on: list[str] | core.ArrayOut[core.StringOut] | None = None,
        provider: str | core.StringOut | None = None,
        lifecycle: core.Lifecycle | None = None,
    ):
        super().__init__(
            name=resource_name,
            args=Ledger.Args(
                permissions_mode=permissions_mode,
                deletion_protection=deletion_protection,
                kms_key=kms_key,
                name=name,
                tags=tags,
                tags_all=tags_all,
                depends_on=depends_on,
                provider=provider,
                lifecycle=lifecycle,
            ),
        )

    @core.schema_args
    class Args(core.Resource.Args):
        deletion_protection: bool | core.BoolOut | None = core.arg(default=None)

        kms_key: str | core.StringOut | None = core.arg(default=None)

        name: str | core.StringOut | None = core.arg(default=None)

        permissions_mode: str | core.StringOut = core.arg()

        tags: dict[str, str] | core.MapOut[core.StringOut] | None = core.arg(default=None)

        tags_all: dict[str, str] | core.MapOut[core.StringOut] | None = core.arg(default=None)
